@@ -7,13 +7,11 @@
 
 import datetime
 import gettext
-import logging
-import os
-import pkg_resources
 from decimal import Decimal
+from logging import info, debug
 from odf.opendocument import OpenDocumentSpreadsheet,  OpenDocumentText,  load
 from odf.style import Footer, FooterStyle, HeaderFooterProperties, Style, TextProperties, TableColumnProperties, Map,  TableProperties,  TableCellProperties, PageLayout, PageLayoutProperties, ParagraphProperties,  ListLevelProperties,  MasterPage
-from odf.number import  CurrencyStyle, CurrencySymbol,  Number, NumberStyle, Text,  PercentageStyle,  DateStyle, Year, Month, Day, Hours, Minutes, Seconds
+from odf.number import  TimeStyle, CurrencyStyle, CurrencySymbol,  Number, NumberStyle, Text,  PercentageStyle,  DateStyle, Year, Month, Day, Hours, Minutes, Seconds, Boolean, BooleanStyle
 from odf.text import P,  H,  Span, ListStyle,  ListLevelStyleBullet,  List,  ListItem, ListLevelStyleNumber,  OutlineLevelStyle,  OutlineStyle,  PageNumber,  PageCount
 from odf.table import Table, TableColumn, TableRow, TableCell,  TableHeaderRows
 from odf.draw import Frame, Image
@@ -23,11 +21,15 @@ import odf.element
 
 from odf.config import ConfigItem, ConfigItemMapEntry, ConfigItemMapIndexed, ConfigItemMapNamed,  ConfigItemSet
 from odf.office import Annotation
-
-from officegenerator.commons import makedirs,  number2column,  number2row,  Coord, Range,  Percentage, Currency
+from officegenerator.commons import number2column,  number2row,  Coord, Range, topLeftCellNone
+from officegenerator.objects.currency import Currency
+from officegenerator.datetime_functions import dtnaive2string
+from officegenerator.objects.percentage import Percentage
+from os import system, path, remove, makedirs
+from pkg_resources import resource_filename
 
 try:
-    t=gettext.translation('officegenerator',pkg_resources.resource_filename("officegenerator","locale"))
+    t=gettext.translation('officegenerator', resource_filename("officegenerator","locale"))
     _=t.gettext
 except:
     _=str
@@ -45,7 +47,6 @@ class ColumnWidthODS:
     XXXL=250
     XXXXL=300
 
-
 class ODS_Read:
     def __init__(self, filename):
         self.doc=load(filename)#doc is only used in this function. All is generated in self.doc
@@ -105,6 +106,8 @@ class ODS_Read:
                 r=datetime.datetime.strptime(datevalue, "%Y-%m-%d").date()
             else:
                 r=datetime.datetime.strptime(datevalue, "%Y-%m-%dT%H:%M:%S")
+        if cell.getAttribute('valuetype')=='time':
+            r="NEED TO DO IT"
         return r
 
     ## Returns an odfcell object
@@ -229,9 +232,28 @@ class ODT(ODF):
             self.doc=OpenDocumentText()
         else:
             self.doc= load(self.template)
+            self.save()#After loading a template it's needed to save file to work with search functions
+            remove(self.filename)#Delete temporal save
         self.cursor=None
         self.cursorParent=self.doc.text
 
+    ## Creates a text header
+    ## @param text String with the header string
+    ## @Level Integer Level of the header
+    def header(self, text, level, after=True):
+        h=H(outlinelevel=level, stylename="Heading_20_{}".format(level), text=text)
+        return self.insertInCursor(h, after)
+
+    def pageBreak(self,  horizontal=False, after=True):    
+        p=P(stylename="PageBreak")#Is an automatic style
+        self.doc.text.addElement(p)
+        if horizontal==True:
+            p=P(stylename="PH")
+        else:
+            p=P(stylename="PV")
+        return self.insertInCursor(p, after)
+
+
     ## @param href must bu added before with addImage
     ## @param width Int or float value
     ## @param height Int or float value to set the images height
@@ -325,18 +347,17 @@ class ODT(ODF):
         self.__setCursor(o)
         return o
 
-    ## Search for a tag type elementes  an returns element and its index. With it, inserts new with replaced text and removes old
+    ## Search for a tag type_ elementes  an returns element and its index. With it, inserts new with replaced text and removes old
     ##
     ## Cursor doesn't change because we replace Text objects in Element Text
     ## @param tag String to search
     ## @param replace String to replace. Can't be None
-    def search_and_replace(self, tag, replace, type=P):
-        e,  textindex=self.search(tag, type) #Places cursor to element
+    ## @param Search in elements with tag P or H. To encapsulate type_ will be a string "P" or "H"
+    def search_and_replace(self, tag, replace, type_="P"):
+        e,  textindex=self.search(tag, type_) #Places cursor to element
         if e==None:
-            print(_("Tag {} hasn't been found"))
             return
 
-
         if replace==None:#Remove paragraph
             print("Replace parameter can't be None. Use '' instead or use search_and_replace_element")
             return
@@ -349,19 +370,20 @@ class ODT(ODF):
                 self.cursorParent.removeChild(e)
         else: #Replace
             e.insertBefore( odf.element.Text(str(to_remove).replace(tag, replace)), to_remove)
-            e.removeChild(to_remove)
+            #print(to_remove.__class__, e.__class__, e.childNodes)
+            debug("THIS CODE FAILS IN ODFPY-1.4.1 AND WORKS IN ODFPY-1.3.6")
+            e.removeChild(to_remove     )
+            
 
     ## Search for a tag in doc an replaces its elemente with the parameter element
     ##
     ## @param tag String to search
     ## @param replace ELement. OdfPy element
-    def search_and_replace_element(self, tag, newelement, type=P):
-        e,  textindex=self.search(tag, type) #Places cursor to element
+    def search_and_replace_element(self, tag, newelement, type_="P"):
+        e,  textindex=self.search(tag, type_) #Places cursor to element
         if e==None:
-            print(_("Tag {} hasn't been found"))
             return
 
-
         if newelement==None:#Remove paragraph
             print("New element can't be None")
             return
@@ -373,22 +395,35 @@ class ODT(ODF):
 
     ## Searchs for the item with a tag. Perhaps is its paren where I'll have to append. Only finds the first one
     ## Returns the element p and the position in its text children
-    def search(self, tag, type=P):
-        for e in self.doc.getElementsByType(type):
+    ## Using templates sometimes you cant search a tag. It's due to sometimes has <span> in the tag. Use odf2xml to detect them
+    ## 20200119 Search_and_replace has problem with tables, we must try to not abuse of them
+    def search(self, tag, type_="P"):
+        if type_=="P":
+             ty=P
+        elif type_=="H":
+             ty=H
+        for e in self.doc.getElementsByType(ty):
+            #print("Searching", tag, "found", str(e))
             if str(e).find(tag)!=-1:
                 self.__setCursor(e)
                 for index, child in enumerate(e.childNodes):
                     #print(index, child)
+                    #print("Searching in for", tag,"-", child , "found", str(e))
                     if str(child).find(tag)!=-1:
                         #print("SEARCH RETURN",  e, index)
                         return e, index
-        print ("tag {} not found".format(tag))
+        print ("Tag {} not found with type {}".format(tag,type_))
         return None, None
 
 
-    ## Converts saved odt to pdf. It will have the same file name but with .pdf extension
-    def convert_to_pdf(self):
-        os.system("lowriter --headless --convert-to pdf '{}'".format(self.filename))
+    ## Converts saved odt to pdf. It will have the same basename but with .pdf extension
+    ## @param output_dir None or dirname. If set, it writes pdf in that directory with the same basename of the filename class attribute
+    def convert_to_pdf(self, output_dir=None):
+        if output_dir is None:
+            s_outdir=""
+        else:
+            s_outdir="--outdir '{}'".format(output_dir)
+        system("lowriter --headless --convert-to pdf '{}' {}".format(self.filename, s_outdir))
 
     def __setCursor(self, e):
         self.cursor=e
@@ -401,7 +436,8 @@ class ODT(ODF):
         if  self.filename==self.template:
             print(_("You can't overwrite a readed odt"))
             return
-        makedirs(os.path.dirname(self.filename))
+        if path.dirname(self.filename)!="":
+            makedirs(path.dirname(self.filename), exist_ok=True)
         self.doc.save( self.filename)
 
     ## Adds an empty paragraph
@@ -430,13 +466,13 @@ class ODT(ODF):
 
 
     ## Creates a table adding it to self.doc
-    ## @param header List with all header strings
+    ## @param hh List with all header strings
     ## @param data Multidimension List with all data objects. Can be str, Decimal, int, datetime, date, Currency, Percentage
     ## @param sizes Integer list with sizes in cm
     ## @param fontsize Integer in pt
     ## @param name str or None. Sets the object name. Appears in LibreOffice navigator. If none table will be named to "Table.Sequence"
     ## @param after True: insert after self.cursor element. False: insert before self.cursor element. None: Just return element
-    def table(self, header, data, sizes, fontsize, name=None, after=True):
+    def table(self, hh, data, sizes, fontsize, name=None, after=True):
         def generate_table_styles():
             s=Style(name="Table.Size{}".format(sum(sizes)), family='table')
             s.addElement(TableProperties(width="{}cm".format(sum(sizes)), align="center", margintop="0.6cm", marginbottom="0.6cm"))
@@ -487,15 +523,18 @@ class ODT(ODF):
             tc = TableCell(stylename="Table.Cell")
             #Parses orientation
             p = P(stylename="Table.ContentsRight.Font{}".format(fontsize))
-            s=Span(text=o)
-            if o.__class__ in (str, datetime.datetime, datetime.date ):
+            s=Span(text=str(o))
+            if o.__class__.__name__  == "datetime":
+                p = P(stylename="Table.Contents.Font{}".format(fontsize))
+                s=Span(text=dtnaive2string(o, "%Y-%m-%d %H:%M:%S"))
+            if o.__class__.__name__ in ("str", "date" ):
                 p = P(stylename="Table.Contents.Font{}".format(fontsize))
                 s=Span(text=str(o))
-            elif o.__class__ in (Currency,  Percentage):
+            elif o.__class__.__name__ in ("Currency", "Percentage", "Money"):
                 if o.isLTZero():
                     p = P(stylename="Table.ContentsRight.FontRed{}".format(fontsize))
                 s=Span(text=o.string())
-            elif o.__class__ in (int, Decimal,  float):
+            elif o.__class__ in ("int", "Decimal",  "float"):
                 if o<0:
                     p = P(stylename="Table.ContentsRight.FontRed{}".format(fontsize))
             p.addElement(s)
@@ -514,11 +553,12 @@ class ODT(ODF):
         headerrow=TableHeaderRows()
         tablerow=TableRow()
         headerrow.addElement(tablerow)
-        for i, head in enumerate(header):
-            p=P(stylename="Table.Heading.Font{}".format(fontsize), text=head)
-            tablecell=TableCell(stylename="Table.HeaderCell")
-            tablecell.addElement(p)
-            tablerow.addElement(tablecell)
+        if hh is not None:
+            for i, head in enumerate(hh):
+                p=P(stylename="Table.Heading.Font{}".format(fontsize), text=head)
+                tablecell=TableCell(stylename="Table.HeaderCell")
+                tablecell.addElement(p)
+                tablerow.addElement(tablecell)
         table.addElement(headerrow)
 
         #Data rows
@@ -549,16 +589,9 @@ class ODT(ODF):
 ## Class with starndard.odt template
 class ODT_Standard(ODT):
     def __init__(self, filename, language="es", country="es"):
-        template=pkg_resources.resource_filename("officegenerator","templates/odt/standard.odt")
+        template=resource_filename("officegenerator","templates/odt/standard.odt")
         ODT.__init__(self, filename, template, language, country)
 
-    ## Creates a text header
-    ## @param text String with the header string
-    ## @Level Integer Level of the header
-    def header(self, text, level, after=True):
-        h=H(outlinelevel=level, stylename="Heading_20_{}".format(level), text=text)
-        return self.insertInCursor(h, after)
-
     ## PH and PV styles are deffined in standard.odtg
     def pageBreak(self,  horizontal=False, after=True):    
         if horizontal==True:
@@ -765,16 +798,20 @@ class OdfCell:
     def generate(self):
         if self.object==None:
             self.object=" - "
-        if self.object.__class__==Currency:
+        if self.object.__class__.__name__ in ["Currency", "Money"]:
             odfcell = TableCell(valuetype="currency", currency=self.object.currency, value=self.object.amount, stylename=self.style)
-        elif self.object.__class__==Percentage:
+        elif self.object.__class__.__name__=="Percentage":
             odfcell = TableCell(valuetype="percentage", value=self.object.value, stylename=self.style)
-        elif self.object.__class__==datetime.datetime:
+        elif self.object.__class__.__name__=="datetime":
             odfcell = TableCell(valuetype="date", datevalue=self.object.strftime("%Y-%m-%dT%H:%M:%S"), stylename=self.style)
-        elif self.object.__class__==datetime.date:
+        elif self.object.__class__.__name__=="time":
+            odfcell = TableCell(valuetype="time", timevalue=self.object.strftime("PT%HH%MM%SS"), stylename=self.style)
+        elif self.object.__class__.__name__=="date":
             odfcell = TableCell(valuetype="date", datevalue=str(self.object), stylename=self.style)
-        elif self.object.__class__ in (Decimal, float,  int):
+        elif self.object.__class__.__name__ in ("Decimal", "float", "int"):
             odfcell= TableCell(valuetype="float", value=self.object,  stylename=self.style)
+        elif self.object.__class__.__name__ =="bool":
+            odfcell= TableCell(valuetype="boolean", booleanvalue=self.object, stylename=self.style)
         else:#strings
             if len(self.object)>0:
                 if self.object[:1]=="=":#Formula
@@ -816,63 +853,72 @@ class OdfSheet:
         self.title=title
         self.widths=None
         self.arr=[]
-        self.setCursorPosition("A1")#Default values
-        self.setSplitPosition("A1")
+        self.freezeAndSelect("A1", "A1", "A1")#Default values
 
+    ## Freeze panels in a sheet and sets the selected cell
+    ##        split/freeze vertical (0|1|2) - 1 = split ; 2 = freeze
+    ##          ##split/freeze horizontal (0|1|2) - 1 = split ; 2 = freeze
+    ##      vertical position = in cell if fixed, in screen unit if frozen
+    ##      horizontal position = in cell if fixed, in screen unit if frozen
+    ##      active zone in the splitted|frozen sheet (0..3 from let to right, top
+    ##  to bottom)
+    ##  #   COMPROBADO CON ODF2XML
+    ##  B1: 
+    ##                <config:config-item config:name="HorizontalSplitMode" config:type="short">2</config:config-item>
+    ##                <config:config-item config:name="VerticalSplitMode" config:type="short">0</config:config-item>
+    ##                <config:config-item config:name="HorizontalSplitPosition" config:type="int">1</config:config-item>
+    ##                <config:config-item config:name="VerticalSplitPosition" config:type="int">0</config:config-item>
+    ##                <config:config-item config:name="ActiveSplitRange" config:type="short">3</config:config-item>
+    ##                <config:config-item config:name="PositionLeft" config:type="int">0</config:config-item>
+    ##                <config:config-item config:name="PositionRight" config:type="int">1</config:config-item>
+    ##                <config:config-item config:name="PositionTop" config:type="int">0</config:config-item>
+    ##                <config:config-item config:name="PositionBottom" config:type="int">0</config:config-item>
+    ## @param freeze_coord, Cell where panels are frrozen. Can be a string or a Coord object.
+    ## @param selected_coord. Cell selected opening sheet. Can be a string or a Coord object.
+    ## @param topLeftCell, topleftcell to show in sheet after opening. Can be a string or a Coord object.
+    def freezeAndSelect(self, freeze_coord, selected_coord, topleftcell_coord=None):
+        if topleftcell_coord==None:
+            topleftcell_coord=topLeftCellNone(freeze_coord, selected_coord)
+        # Creates Coord objects
+        freeze_coord=Coord.assertCoord(freeze_coord)
+        selected_coord=Coord.assertCoord(selected_coord)
+        topleftcell_coord=Coord.assertCoord(topleftcell_coord)
 
-    def setSplitPosition(self, coord):
-        """
-                split/freeze vertical (0|1|2) - 1 = split ; 2 = freeze
-    split/freeze horizontal (0|1|2) - 1 = split ; 2 = freeze
-    vertical position = in cell if fixed, in screen unit if frozen
-    horizontal position = in cell if fixed, in screen unit if frozen
-    active zone in the splitted|frozen sheet (0..3 from let to right, top
-to bottom)
-
-
-#   COMPROBADO CON ODF2XML
-B1: 
-              <config:config-item config:name="HorizontalSplitMode" config:type="short">2</config:config-item>
-              <config:config-item config:name="VerticalSplitMode" config:type="short">0</config:config-item>
-              <config:config-item config:name="HorizontalSplitPosition" config:type="int">1</config:config-item>
-              <config:config-item config:name="VerticalSplitPosition" config:type="int">0</config:config-item>
-              <config:config-item config:name="ActiveSplitRange" config:type="short">3</config:config-item>
-              <config:config-item config:name="PositionLeft" config:type="int">0</config:config-item>
-              <config:config-item config:name="PositionRight" config:type="int">1</config:config-item>
-              <config:config-item config:name="PositionTop" config:type="int">0</config:config-item>
-              <config:config-item config:name="PositionBottom" config:type="int">0</config:config-item>
-
-"""
-        def setActiveSplitRange():
-            """
-                Creo que es la posición tras los ejes.
-            """
-            if (self.horizontalSplitPosition!="0" and self.verticalSplitPosition=="0"):
-                return "3"
-            if (self.horizontalSplitPosition=="0" and self.verticalSplitPosition!="0"):
-                return "2"
-            if self.horizontalSplitPosition!="0" and self.verticalSplitPosition!="0":
-                return "3"
-            return "2"
-
-        coord=Coord.assertCoord(coord)
-        self.horizontalSplitPosition=str(coord.letterIndex())
-        self.verticalSplitPosition=str(coord.numberIndex())
+        #Sets cursor position
+        self.cursorPositionX=selected_coord.letterIndex()
+        self.cursorPositionY=selected_coord.numberIndex()
+    
+        #Sets freeze position and modes
+        self.horizontalSplitPosition=str(freeze_coord.letterIndex())
+        self.verticalSplitPosition=str(freeze_coord.numberIndex())
         self.horizontalSplitMode="0" if self.horizontalSplitPosition=="0" else "2"
         self.verticalSplitMode="0" if self.verticalSplitPosition=="0" else "2"
-        self.activeSplitRange=setActiveSplitRange()
-        self.positionTop="0"
-        self.positionBottom="0" if self.verticalSplitPosition=="0" else str(self.verticalSplitPosition)
-        self.positionLeft="0"
-        self.positionRight="0" if self.horizontalSplitPosition=="0" else str(self.horizontalSplitPosition)
-
-    def setCursorPosition(self, coord):
-        """
-            Sets the cursor in a Sheet
-        """
-        coord=Coord.assertCoord(coord)
-        self.cursorPositionX=coord.letterIndex()
-        self.cursorPositionY=coord.numberIndex()
+        
+        #Sets active split range and top left cell position
+        if self.horizontalSplitPosition!="0" and self.verticalSplitPosition=="0":#C1 WORKS
+            self.activeSplitRange="3"
+            self.positionTop="0"
+            self.positionBottom=str(topleftcell_coord.numberIndex())
+            self.positionLeft="0"
+            self.positionRight=str(topleftcell_coord.letterIndex())
+        elif self.horizontalSplitPosition=="0" and self.verticalSplitPosition!="0":#A3 WORKS
+            self.activeSplitRange="2"
+            self.positionTop="0"
+            self.positionBottom=str(topleftcell_coord.numberIndex())
+            self.positionLeft=str(topleftcell_coord.letterIndex())
+            self.positionRight="0"
+        elif self.horizontalSplitPosition!="0" and self.verticalSplitPosition!="0": # C3  WORKS
+            self.activeSplitRange="3"
+            self.positionTop="0"
+            self.positionBottom=str(topleftcell_coord.numberIndex())
+            self.positionLeft="0"
+            self.positionRight=str(topleftcell_coord.letterIndex())
+        else:#A1 WORKS
+            self.activeSplitRange="2"
+            self.positionTop="0"
+            self.positionBottom=str(topleftcell_coord.numberIndex())
+            self.positionLeft=str(topleftcell_coord.letterIndex())
+            self.positionRight=str(topleftcell_coord.letterIndex())
 
     ## Sets a comment in the givven cell
     ## @param coord can be Coord o Coord.string()
@@ -929,10 +975,10 @@ B1:
                     for j, column in enumerate(row):
                         style=guess_ods_style(color_or_style, result[i][j])
                         self.addCell(OdfCell(Coord(coord.string()).addColumn(j).addRow(i), result[i][j], style))
-                else: #Any value not list if row.__class__ in (int, str, float, datetime.datetime,  datetime.date, Currency, Percentage,  Decimal):#Una lista de una columna
+                else: #Any value not list if row.__class__ in (int, str, float, datetime.datetime,  datetime.date, Currency, Percentage,  Decimal, bool):#Una lista de una columna
                     style=guess_ods_style(color_or_style, result[i])
                     self.addCell(OdfCell(Coord(coord.string()).addRow(i), result[i], style))
-        else: #Any value not list#result.__class__ in (str, int, float, datetime.datetime, datetime.date,  Currency, Percentage, Decimal):#Un solo valor
+        else: #Any value not list#result.__class__ in (str, int, float, datetime.datetime, datetime.date,  Currency, Percentage, Decimal,bool):#Un solo valor
             style=guess_ods_style(color_or_style, result)  
             self.addCell(OdfCell(coord, result, style))
 
@@ -1078,7 +1124,8 @@ class ODS(ODF):
         if  filename==None:
             filename=self.filename
 
-        makedirs(os.path.dirname(filename))
+        if path.dirname(filename)!="":
+            makedirs(path.dirname(filename), exist_ok=True)
         self.doc.save(filename)
 
     def setActiveSheet(self, value):
@@ -1149,9 +1196,15 @@ class ODSStyleColor:
 
         date = Style(name=self.name+"Date", datastylename="Date",parentstylename=self.name+"Left", family="table-cell")
         doc.styles.addElement(date)
+        
+        time = Style(name=self.name+"Time", datastylename="Time",parentstylename=self.name+"Left", family="table-cell")
+        doc.styles.addElement(time)
 
         integer = Style(name=self.name+"Integer", family="table-cell",  datastylename="Integer",parentstylename=self.name+"Right")
         doc.styles.addElement(integer)
+        
+        boolean = Style(name=self.name+"Boolean", family="table-cell",  datastylename="Boolean",parentstylename=self.name+"Right")
+        doc.styles.addElement(boolean)
 
         decimal2= Style(name=self.name+"Decimal2", family="table-cell",  datastylename="Decimal2",parentstylename=self.name+"Right")
         doc.styles.addElement(decimal2)
@@ -1210,7 +1263,16 @@ class ODSStyleColorManager:
         date_style.addElement(Minutes(style="long"))
         date_style.addElement(Text(text=":"))
         date_style.addElement(Seconds(style="long"))
-        doc.styles.addElement(date_style)#NO SERIA ESTE UN AUTOMATICO????
+        doc.styles.addElement(date_style)#NO SERIA ESTE UN AUTOMATICO????        
+        
+        # Time
+        time_style = TimeStyle(name="Time") #, language="lv", country="LV")
+        time_style.addElement(Hours(style="long"))
+        time_style.addElement(Text(text=":"))
+        time_style.addElement(Minutes(style="long"))
+        time_style.addElement(Text(text=":"))
+        time_style.addElement(Seconds(style="long"))
+        doc.styles.addElement(time_style)#NO SERIA ESTE UN AUTOMATICO????
 
         #Date
         date_style = DateStyle(name="Date") #, language="lv", country="LV")
@@ -1256,6 +1318,17 @@ class ODSStyleColorManager:
         ns2.addElement(Number(decimalplaces="6", minintegerdigits="1", grouping="true"))
         ns2.addElement(Map(condition="value()>=0", applystylename="Decimal6Black"))
         doc.styles.addElement(ns2)
+        
+        #Boolean
+        ns1 = BooleanStyle(name="BooleanBlack", volatile="true")
+        ns1.addElement(Boolean())
+        doc.styles.addElement(ns1)
+
+        ns2 = BooleanStyle(name="Boolean")
+        ns2.addElement(TextProperties(color="#ff0000"))
+        ns2.addElement(Boolean())
+        ns2.addElement(Map(condition="value()==1", applystylename="BooleanBlack"))
+        doc.styles.addElement(ns2)
             
 
     def generate_ods_styles(self, doc, currencymanager):
@@ -1296,22 +1369,26 @@ class ODS_Write(ODS):
 ## @return String with the style 
 def guess_ods_style(color_or_style, object):
     if color_or_style in ["Green", "GrayDark", "GrayLight", "Orange", "Yellow", "White", "Blue", "Red", "Normal"]:
-        if object.__class__==str:
+        if object.__class__.__name__=="str":
             return color_or_style + "Left"
-        elif object.__class__==int:
+        elif object.__class__.__name__=="int":
             return color_or_style + "Integer"
-        elif object.__class__==Currency:
+        elif object.__class__.__name__ in ["Currency", "Money" ]:
             return color_or_style + object.currency
-        elif object.__class__==Percentage:
+        elif object.__class__.__name__=="Percentage":
             return color_or_style + "Percentage"
-        elif object.__class__ in (Decimal, float):
+        elif object.__class__.__name__ in ("Decimal", "float"):
             return color_or_style +  "Decimal2"
-        elif object.__class__==datetime.datetime:
+        elif object.__class__.__name__=="datetime":
             return color_or_style + "Datetime"
-        elif object.__class__==datetime.date:
+        elif object.__class__.__name__=="date":
             return color_or_style + "Date"
+        elif object.__class__.__name__=="time":
+            return color_or_style + "Time"
+        elif object.__class__.__name__=="bool":
+            return color_or_style + "Boolean"
         else:
-            logging.info("guess_ods_style not guessed",  object.__class__)
+            info("guess_ods_style not guessed",  object.__class__)
             return "NormalLeft"
     else:
         return color_or_style
